#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_MAXNUMMAG_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_MAXNUMMAG_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/maxnummag.hpp>

#endif
